**********************
The sherpa.data module
**********************

.. currentmodule:: sherpa.data

.. automodule:: sherpa.data

   .. rubric:: Classes
               
   .. autosummary::
      :toctree: api
   
      Data
      Data1D
      Data1DAsymmetricErrs
      Data1DInt
      Data2D
      Data2DInt
      DataSimulFit
      BaseData
      DataSpace1D
      DataSpace2D
      DataSpaceND
      Filter
      IntegratedDataSpace1D
      IntegratedDataSpace2D

Class Inheritance Diagram
=========================

.. inheritance-diagram:: BaseData Data Data1D Data1DAsymmetricErrs Data1DInt Data2D Data2DInt DataSimulFit
   :parts: 1

.. inheritance-diagram:: DataSpace1D DataSpace2D DataSpaceND IntegratedDataSpace1D IntegratedDataSpace2D
   :parts: 1
